MicroRaiden

### Transfer Requested

#### Read this article and support the publisher -

#### by transfering TKN tokens.

Account
Balance

##### No accounts found!

##### You may need to unlock your account on your Web3 provider (Metamask/Mist/Parity)

##### Invalid contract response!

##### Web3 provider failed to get proper contract response. Please, check your provider is in the right network and synced!

##### Loading channel

##### A channel was found for this address.

Status
opened closed settled invalid
Remaining Balance
TKN

##### Press the Sign button to authorize the transfer or make another action

##### No channel was found registered for this account on this website.

##### In order to proceed...

1. Make a desired token deposit to open a channel with this site.
2. For each transfer, sign a message confirming the balance with the new transferred amount.
   PS: the balance is the cumulative sum of all previous payments and current one. It may also be shown multiplied by as many decimals as token decimals (up to 18).

##### The transactions are being processed.

##### Please authorize with your Ethereum client.

##### Insufficient deposited funds on this channel.

Current Deposit
TKN
Remaining Balance
TKN

##### In order to proceed, make a new deposit of at least TKN tokens

##### and sign the transaction